@@ -3,7 +3,7 @@ package Bundle::SYP;
 # ABSTRACT: SYP's cozy environment
 
 use strict;
-our $VERSION = '0.1'; # VERSION
+our $VERSION = '0.2'; # VERSION
 
 1;
 
@@ -19,7 +19,7 @@ Bundle::SYP - SYP's cozy environment
 
 =head1 VERSION
 
-version 0.1
+version 0.2
 
 =head1 SYNOPSIS
 
@@ -27,6 +27,10 @@ version 0.1
 
 =head1 CONTENTS
 
+Object::ID
+
+Term::ANSIColor
+
 AnyEvent
 
 App::Ack
@@ -35,14 +39,18 @@ App::cpanminus
 
 App::cpanoutdated
 
-DBD::SQLite
-
-DBI
+Config::General
 
 DB_File
 
+Daemon::Generic
+
 Data::Printer
 
+DateTime::Format::Strptime
+
+Devel::NYTProf
+
 Devel::REPL
 
 Devel::REPL::Plugin::DataPrinter
@@ -75,6 +83,8 @@ Dist::Zilla::PluginBundle::TestingMania
 
 EV
 
+File::Slurp
+
 Geo::Distance
 
 Geo::GoogleEarth::Pluggable
@@ -93,12 +103,16 @@ LWP::Simple
 
 Mojolicious
 
-MongoDB
-
 Moose
 
+Number::Format
+
+Perl::Critic
+
 Perl::Tags
 
+Perl::Tidy
+
 Pod::Elemental
 
 Pod::Simple
@@ -135,6 +149,8 @@ Unicode::CheckUTF8
 
 WWW::Curl
 
+XML::SAX::ExpatXS
+
 common::sense
 
 lexicals
